TraceServer

Trait TraceServer 

pub trait TraceServer:
    Sized
    + Send
    + Sync
    + 'static {
    // Required methods
    fn block_traces(
        &self,
        block_hash: H256,
    ) -> RpcResult<Option<LocalizedBlockTrace>>;
    fn filter_traces(
        &self,
        filter: TraceFilter,
    ) -> RpcResult<Option<Vec<LocalizedTrace>>>;
    fn transaction_traces(
        &self,
        tx_hash: H256,
    ) -> RpcResult<Option<Vec<LocalizedTrace>>>;
    fn epoch_traces(&self, epoch: EpochNumber) -> RpcResult<Option<EpochTrace>>;

    // Provided method
    fn into_rpc(self) -> RpcModule<Self> { ... }
}
Server trait implementation for the Trace RPC API.

Required Methods

fn block_traces( &self, block_hash: H256, ) -> RpcResult<Option<LocalizedBlockTrace>>

Returns all traces produced at the given block.

fn filter_traces( &self, filter: TraceFilter, ) -> RpcResult<Option<Vec<LocalizedTrace>>>

Returns all traces matching the provided filter.

fn transaction_traces( &self, tx_hash: H256, ) -> RpcResult<Option<Vec<LocalizedTrace>>>

Returns all traces produced at the given transaction.

fn epoch_traces(&self, epoch: EpochNumber) -> RpcResult<Option<EpochTrace>>

Return all traces of both spaces in an epoch.

Provided Methods

fn into_rpc(self) -> RpcModule<Self>

Collects all the methods and subscriptions defined in the trait and adds them into a single RpcModule.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors